# Cup Manager

A plugin for [PyPlanet](https://pypla.net/).

This plugin will handle hosting a cup competition in Trackmania, Maniaplanet, and Shootmania. It provides a competition
host with the following:

* Manage mode scripts and settings to ensure consistent competitions
* Record player score results and sum totals across multiple maps
* Provide player placement status information and podium results
* Use result totals to pay planets to players in batch
* Export results in multiple formats including Csv and Discord

The following games and modes have been tested and shown to have some level of functionality. In general, this plugin
will work with any script mode which supports the scores callback.

* Trackmania - Timeattack, Rounds, Laps, MedalAttack, Speedtrap
* Maniaplanet - Timeattack, Rounds, Laps
* Shootmania - Melee, Elite, Royal, Siege, Infection, Combo

See [the usage information](https://github.com/skybaks/pyplanet-cup_manager/blob/master/usage.md) to get started
integrating with your PyPlanet instance and running your competition.
